==> sdx-2.2.2-src.zip: sdx-2.2.2/src/java/fr/gouv/culture/sdx/repository/JDBCRepositoryConnection.java <==
/*
SDX: Documentary System in XML.
Copyright (C) 2000, 2001, 2002  Ministere de la culture et de la communication (France), AJLSM

Ministere de la culture et de la communication,
Mission de la recherche et de la technologie
3 rue de Valois, 75042 Paris Cedex 01 (France)
mrt@culture.fr, michel.bottin@culture.fr

AJLSM, 17, rue Vital Carles, 33000 Bordeaux (France)
sevigny@ajlsm.com

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the
Free Software Foundation, Inc.
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
or connect to:
http://www.fsf.org/copyleft/gpl.html
*/
package fr.gouv.culture.sdx.repository;

import fr.gouv.culture.sdx.exception.SDXException;
import fr.gouv.culture.sdx.exception.SDXExceptionCode;
import org.apache.avalon.excalibur.datasource.DataSourceComponent;

import java.sql.Connection;
import java.sql.SQLException;

/**This classes represents a SQL Connection to JDBC Source
 *
 */
public class JDBCRepositoryConnection extends AbstractRepositoryConnection {

    /** The SQL connection. */
    private Connection conn;

    /** The data source. */
    private DataSourceComponent dataSource;

    /**
     * Creates a connection using a standard SQL Connection.
     *
     * @param dataSource    The component from cocoon representing the database
     */
    public JDBCRepositoryConnection(DataSourceComponent dataSource) throws SQLException {
        this.dataSource = dataSource;
        this.conn = dataSource.getConnection();
        this.conn.setAutoCommit(false);//defaulted
    }

    /**
     * Commit all pending operations within this active connection.
     */
    public void commit() throws SDXException {
        try {
            if (this.conn != null) this.conn.commit();
        } catch (SQLException e) {
            String[] args = new String[2];
            args[0] = dataSource.toString();
            args[1] = e.getMessage();
            throw new SDXException(logger, SDXExceptionCode.ERROR_COMMIT, args, e);
        }
    }

    /**
     * Undo all pending operations within with this connection.
     */
    public void rollback() throws SDXException {
        try {
            if (this.conn != null) this.conn.rollback();
        } catch (SQLException e) {
            String[] args = new String[2];
            args[0] = dataSource.toString();
            args[1] = e.getMessage();
            throw new SDXException(logger, SDXExceptionCode.ERROR_ROLLBACK, args, e);
        }
    }

    /**
     * Sets this connection in autocommit mode or not.
     *
     * @param   autoCommit      true enables auto-commit ; false disables auto-commit.
     */
    public void setAutoCommit(boolean autoCommit) throws SDXException {
        try {
            if (this.conn != null) this.conn.setAutoCommit(autoCommit);
        } catch (SQLException e) {
            String[] args = new String[2];
            args[0] = dataSource.toString();
            args[1] = e.getMessage();
            throw new SDXException(logger, SDXExceptionCode.ERROR_SET_AUTO_COMMIT, args, e);
        }
    }

    /**
     * Returns the SQL connection to the datasource component
     */
    public Connection getConnection() {
        return this.conn;
    }

    /**
     *Returns the datasource component from which this connection was derived
     */
    public DataSourceComponent getDataSource() {
        return this.dataSource;
    }

    /** Set's the logger for this connection.
     *
     * @param logger    The logger to use.
     */
    public void enableLogging(org.apache.avalon.framework.logger.Logger logger) {
        this.logger = logger;
    }

    /**Releases the SQL Connection to the datasource
     *
     * @throws SDXException
     */
    protected void releaseSqlConnection() throws SDXException {
        try {
            this.conn.close();
        } catch (SQLException e) {
            String[] args = new String[1];
            args[0] = e.getMessage();
            throw new SDXException(logger, SDXExceptionCode.ERROR_CLOSE_SQL_CONNECTION, args, e);
        }
    }
}

==> sdx-2.3b1-src.zip: sdx-2.3b1/src/java/fr/gouv/culture/sdx/repository/JDBCRepositoryConnection.java <==
/*
SDX: Documentary System in XML.
Copyright (C) 2000, 2001, 2002  Ministere de la culture et de la communication (France), AJLSM

Ministere de la culture et de la communication,
Mission de la recherche et de la technologie
3 rue de Valois, 75042 Paris Cedex 01 (France)
mrt@culture.fr, michel.bottin@culture.fr

AJLSM, 17, rue Vital Carles, 33000 Bordeaux (France)
sevigny@ajlsm.com

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the
Free Software Foundation, Inc.
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
or connect to:
http://www.fsf.org/copyleft/gpl.html
*/
package fr.gouv.culture.sdx.repository;

import fr.gouv.culture.sdx.exception.SDXException;
import fr.gouv.culture.sdx.exception.SDXExceptionCode;
import org.apache.avalon.excalibur.datasource.DataSourceComponent;

import java.sql.Connection;
import java.sql.SQLException;

/**This classes represents a SQL Connection to JDBC Source
 *
 */
public class JDBCRepositoryConnection extends AbstractRepositoryConnection {

    /** The SQL connection. */
    private Connection _conn;

    /** The data source. */
    private DataSourceComponent dataSource;

    /**
     * Creates a connection using a standard SQL Connection.
     *
     * @param dataSource    The component from cocoon representing the database
     */
    public JDBCRepositoryConnection(DataSourceComponent dataSource) throws SQLException {
        this.dataSource = dataSource;
        this._conn = dataSource.getConnection();
        this._conn.setAutoCommit(false);//defaulted
    }

    public JDBCRepositoryConnection(Connection conn) throws SQLException {
        this._conn = conn;
        this._conn.setAutoCommit(false);//defaulted
    }


    /**
     * Commit all pending operations within this active connection.
     */
    public void commit() throws SDXException {
        try {
            if (this._conn != null) this._conn.commit();
        } catch (SQLException e) {
            String[] args = new String[2];
            args[0] = dataSource.toString();
            args[1] = e.getMessage();
            throw new SDXException(super.getLog(), SDXExceptionCode.ERROR_COMMIT, args, e);
        }
    }

    /**
     * Undo all pending operations within with this connection.
     */
    public void rollback() throws SDXException {
        try {
            if (this._conn != null) this._conn.rollback();
        } catch (SQLException e) {
            String[] args = new String[2];
            args[0] = dataSource.toString();
            args[1] = e.getMessage();
            throw new SDXException(super.getLog(), SDXExceptionCode.ERROR_ROLLBACK, args, e);
        }
    }

    /**
     * Sets this connection in autocommit mode or not.
     *
     * @param   autoCommit      true enables auto-commit ; false disables auto-commit.
     */
    public void setAutoCommit(boolean autoCommit) throws SDXException {
        try {
            if (this._conn != null) this._conn.setAutoCommit(autoCommit);
        } catch (SQLException e) {
            String[] args = new String[2];
            args[0] = dataSource.toString();
            args[1] = e.getMessage();
            throw new SDXException(super.getLog(), SDXExceptionCode.ERROR_SET_AUTO_COMMIT, args, e);
        }
    }

    /**
     * Returns the SQL connection to the datasource component
     */
    public Connection getConnection() {
        return this._conn;
    }

    /**
     *Returns the datasource component from which this connection was derived
     */
    public DataSourceComponent getDataSource() {
        return this.dataSource;
    }

    /**Releases the SQL Connection to the datasource
     *
     * @throws SDXException
     */
    protected void releaseSqlConnection() throws SDXException {
        try {
            this._conn.close();
        } catch (SQLException e) {
            String[] args = new String[1];
            args[0] = e.getMessage();
            throw new SDXException(super.getLog(), SDXExceptionCode.ERROR_CLOSE_SQL_CONNECTION, args, e);
        }
    }
}
